@@ -74,11 +74,6 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
-/*
-/*	Wietse Venema
-/*	Google, Inc.
-/*	111 8th Avenue
-/*	New York, NY 10011, USA
 /*--*/
 
 /* System library. */
@@ -418,7 +413,8 @@ static int load_pem_object(pem_load_state_t *st)
 		   && strcmp(name, PEM_STRING_DSA) == 0)) {
 	load_pkey(st, pkey_type, buf, buflen);
     } else if (!st->mixed) {
-       msg_warn("loading %s: ignoring PEM type: %s", st->source, name);
+	msg_warn("error loading %s: unexpected PEM type: %s", st->source, name);
+	st->state = PEM_LOAD_STATE_NOGO;
     }
     OPENSSL_free(name);
     OPENSSL_free(header);
@@ -694,7 +690,6 @@ int     main(int argc, char *argv[])
     int     ch;
     int     mixed = 0;
     int     ret;
-    char   *key_file = 0;
     SSL_CTX *ctx;
 
 #if OPENSSL_VERSION_NUMBER < 0x10100000L
@@ -712,11 +707,8 @@ int     main(int argc, char *argv[])
 	tls_print_errors();
 	exit(1);
     }
-    while ((ch = GETOPT(argc, argv, "mk:")) > 0) {
+    while ((ch = GETOPT(argc, argv, "m")) > 0) {
 	switch (ch) {
-	case 'k':
-	    key_file = optarg;
-	    break;
 	case 'm':
 	    mixed = 1;
 	    break;
@@ -730,9 +722,7 @@ int     main(int argc, char *argv[])
     if (argc < 1)
 	usage();
 
-    if (key_file)
-	ret = set_cert_stuff(ctx, "any", argv[0], key_file) == 0;
-    else if (mixed)
+    if (mixed)
 	ret = load_mixed_file(ctx, argv[0]);
     else
 	ret = load_chain_files(ctx, argv[0]);
